==> nezha-compute-common-1.24.6-20180612.030446-2-sources.jar: cn/com/duiba/nezha/compute/common/model/pacing/AutoMatchInfo.java <==
package cn.com.duiba.nezha.compute.common.model.pacing;

/**
 * Created by jiali on 2018/4/12.
 */
public  class  AutoMatchInfo
{
    Long enablePeriod; //开启时间
    Boolean enable; //开关
    Long convertCost; //转化成本
    EffectLog effectLog; //效果日志
    Long convert; //智能匹配转化
    Long cost;    //智能匹配消耗

    public void setConvertCost(Long convertCost) {
        this.convertCost = convertCost;
    }

    public void setEffectLog(EffectLog effectLog) {
        this.effectLog = effectLog;
    }

    public void setEnable(boolean enable) {
        this.enable = enable;
    }

    public void setEnablePeriod(Long enablePeriod) {
        this.enablePeriod = enablePeriod;
    }

    public void setConvert(Long convert) {
        this.convert = convert;
    }

    public void setCost(Long cost) {
        this.cost = cost;
    }

    public class EffectLog
    {
        Long tag = 0l;     // 0 = 普通流量 1 = 劣质流量  2 = 优质流量
        double pcvr;  //劣质流量预估转化率
        double pctr;
        double arpu;

        public void setArpu(double arpu) {
            this.arpu = arpu;
        }

        public void setPctr(double pctr) {
            this.pctr = pctr;
        }

        public void setPcvr(double pcvr) {
            this.pcvr = pcvr;
        }

        public void setTag(Long tag) {
            this.tag = tag;
        }

        public double getArpu() {
            return arpu;
        }

        public double getPctr() {
            return pctr;
        }

        public double getPcvr() {
            return pcvr;
        }

        public Long getTag() {
            return tag;
        }
    }

    public EffectLog getEffectLog() {
        return effectLog;
    }

    public boolean getEnable() {
        return this.enable;
    }

    public Long getConvert() {
        return convert;
    }

    public Long getConvertCost() {
        return convertCost;
    }

    public Long getCost() {
        return cost;
    }
}

==> nezha-compute-common-1.26.5-20181010.031909-1-sources.jar: cn/com/duiba/nezha/compute/common/model/pacing/AutoMatchInfo.java <==
package cn.com.duiba.nezha.compute.common.model.pacing;

/**
 * Created by jiali on 2018/4/12.
 */
public  class  AutoMatchInfo
{
    Long enablePeriod; //开启时间
    Boolean enable; //开关
    Long convertCost; //转化成本
    EffectLog effectLog; //效果日志
    Long convert; //智能匹配当天转化
    Long cost;    //智能匹配当天消耗
    Long launch;
    Long click;

    public void setConvertCost(Long convertCost) {
        this.convertCost = convertCost;
    }

    public void setEffectLog(EffectLog effectLog) {
        this.effectLog = effectLog;
    }

    public void setEnable(boolean enable) {
        this.enable = enable;
    }

    public void setEnablePeriod(Long enablePeriod) {
        this.enablePeriod = enablePeriod;
    }

    public void setConvert(Long convert) {
        this.convert = convert;
    }

    public void setCost(Long cost) {
        this.cost = cost;
    }

    public class EffectLog
    {
        Long tag = 0l;     // 0 = 普通流量 1 = 劣质流量  2 = 优质流量
        double pcvr;  //劣质流量预估转化率
        double pctr;
        double arpu;

        public void setArpu(double arpu) {
            this.arpu = arpu;
        }

        public void setPctr(double pctr) {
            this.pctr = pctr;
        }

        public void setPcvr(double pcvr) {
            this.pcvr = pcvr;
        }

        public void setTag(Long tag) {
            this.tag = tag;
        }

        public double getArpu() {
            return arpu;
        }

        public double getPctr() {
            return pctr;
        }

        public double getPcvr() {
            return pcvr;
        }

        public Long getTag() {
            return tag;
        }
    }

    public EffectLog getEffectLog() {
        return effectLog;
    }

    public boolean getEnable() {
        return this.enable;
    }

    public Long getConvert() {
        return convert;
    }

    public Long getConvertCost() {
        return convertCost;
    }

    public Long getCost() {
        return cost;
    }

    public void setLaunch(Long launch) {
        this.launch = launch;
    }

    public void setClick(Long click) {
        this.click = click;
    }

    public Long getClick() {
        return click;
    }

    public Long getLaunch() {
        return launch;
    }
}
